==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/DataLegendStylingRowEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendStylingRowEventArgsDescription } from "./DataLegendStylingRowEventArgsDescription";
/**
 * @hidden
 */
export let DataLegendStylingRowEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataLegendStylingRowEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DataLegendStylingRowEventArgsDescriptionMetadata.a == null) {
                DataLegendStylingRowEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataLegendStylingRowEventArgsDescriptionMetadata.c(DataLegendStylingRowEventArgsDescriptionMetadata.a);
            }
            if (a.j(DataLegendStylingRowEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(DataLegendStylingRowEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("BadgeShape", "ExportedType:string:LegendItemBadgeShape");
            a.item("BadgeShape@names", "Automatic;Circle;Line;Square;Marker;Bar;Column;Hidden");
            a.item("IsBadgeVisible", "Boolean");
            a.item("IsRowVisible", "Boolean");
            a.item("SeriesIndex", "Number:int");
            a.item("SeriesTitle", "String");
            a.item("TitleText", "String");
            a.item("TitleTextColor", "Brush");
        }
        static d(a) {
            DataLegendStylingRowEventArgsDescriptionMetadata.b(a);
            a.aa("DataLegendStylingRowEventArgs", () => new DataLegendStylingRowEventArgsDescription());
            a.z("DataLegendStylingRowEventArgs", DataLegendStylingRowEventArgsDescriptionMetadata.a);
        }
    }
    DataLegendStylingRowEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(DataLegendStylingRowEventArgsDescriptionMetadata, 'DataLegendStylingRowEventArgsDescriptionMetadata');
    DataLegendStylingRowEventArgsDescriptionMetadata.a = null;
    return DataLegendStylingRowEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/DataLegendStylingRowEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendStylingRowEventArgsDescription } from "./DataLegendStylingRowEventArgsDescription";
/**
 * @hidden
 */
export let DataLegendStylingRowEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataLegendStylingRowEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DataLegendStylingRowEventArgsDescriptionMetadata.a == null) {
                DataLegendStylingRowEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataLegendStylingRowEventArgsDescriptionMetadata.c(DataLegendStylingRowEventArgsDescriptionMetadata.a);
            }
            if (a.k(DataLegendStylingRowEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(DataLegendStylingRowEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("BadgeShape", "ExportedType:string:LegendItemBadgeShape");
            a.item("BadgeShape@names", "Automatic;Circle;Line;Square;Marker;Bar;Column;Hidden");
            a.item("IsBadgeVisible", "Boolean");
            a.item("IsRowVisible", "Boolean");
            a.item("SeriesIndex", "Number:int");
            a.item("SeriesTitle", "String");
            a.item("TitleText", "String");
            a.item("TitleTextColor", "Brush");
        }
        static d(a) {
            DataLegendStylingRowEventArgsDescriptionMetadata.b(a);
            a.ac("DataLegendStylingRowEventArgs", () => new DataLegendStylingRowEventArgsDescription());
            a.ab("DataLegendStylingRowEventArgs", DataLegendStylingRowEventArgsDescriptionMetadata.a);
        }
    }
    DataLegendStylingRowEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(DataLegendStylingRowEventArgsDescriptionMetadata, 'DataLegendStylingRowEventArgsDescriptionMetadata');
    DataLegendStylingRowEventArgsDescriptionMetadata.a = null;
    return DataLegendStylingRowEventArgsDescriptionMetadata;
})();
